@@ -15,7 +15,7 @@ else:
 class ModelDict(CachedDict):
     """
     Dictionary-style access to a model. Populates a cache and a local in-memory
-    to avoid multiple hits to the database.
+    store to avoid multiple hits to the database.
 
     Specifying ``instances=True`` will cause the cache to store instances rather
     than simple values.
@@ -45,6 +45,9 @@ class ModelDict(CachedDict):
 
         super(ModelDict, self).__init__(*args, **kwargs)
 
+        cls_name = type(self).__name__
+        model_name = model.__name__
+
         self.key = key
         self.value = value
 
@@ -52,8 +55,8 @@ class ModelDict(CachedDict):
         self.instances = instances
         self.auto_create = auto_create
 
-        self.cache_key = 'ModelDict:%s:%s' % (model.__name__, self.key)
-        self.last_updated_cache_key = 'ModelDict.last_updated:%s:%s' % (model.__name__, self.key)
+        self.cache_key = '%s:%s:%s' % (cls_name, model_name, self.key)
+        self.last_updated_cache_key = '%s.last_updated:%s:%s' % (cls_name, model_name, self.key)
 
         request_finished.connect(self._cleanup)
         post_save.connect(self._post_save, sender=model)
